@@ -75,7 +75,7 @@ def _deserialize_conn_config(conn_config: mysql_config_pb2.MySQLConnConfig) -> p
 
 
 @beam.typehints.with_input_types(Text)
-@beam.typehints.with_output_types(beam.typehints.Iterable[Tuple[Text, Text, Any]])
+@beam.typehints.with_output_types(beam.typehints.Dict[Text, Any])
 class _ReadMySQLDoFn(beam.DoFn):
 
     def __init__(self,
@@ -83,7 +83,7 @@ class _ReadMySQLDoFn(beam.DoFn):
         super(_ReadMySQLDoFn, self).__init__()
         self.mysql_config = json_format.MessageToDict(mysql_config)
 
-    def process(self, query: Text) -> Iterable[Tuple[Text, Text, Any]]:
+    def process(self, query: Text) -> Dict[Text, Any]:
         client = pymysql.connect(**self.mysql_config)
         cursor = client.cursor()
         cursor.execute(query)
